==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/eo/heo38.h <==
/* @lastChanged: "1998-09-04  9:41"

  * @filename:   heo38k.h
  * @purpose:    "COM"
  * @release:    7.2.0.0
  * @see:        "-.-"
  *
  * @copyright:  "Copyright by SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*/


#ifndef HEO38_H
#define HEO38_H

externC void eo38CoCreateInstance ( tsp_dcom_co_create_instance_parms * parms );

externC void eo38CoGetClassObject ( tsp_dcom_co_create_instance_parms * parms );

externC BOOLEAN eo38CoInitialize ( void );

externC void eo38IIdILiveCacheSpec ( tsp_c16 * iid );

externC void eo38InitializeDebugServer (tsp_dcom_co_create_instance_parms * parms);

externC void eo38ReleaseInstance ( tsp_dcom_release_instance_parms * parms );

externC void eo38ReleaseProxies ();

externC void eo38RemoveProxy ( tsp00_Uint4 session );

externC void eo38UnInitialize ( void );

externC void eo38VDcomCreateInstance ( tsp_dcom_co_create_instance_parms * parms );

externC void os38kVDcomMonOpen ( tsp_dcom_monitor_parms * parms );

externC void os38kVDcomMonNext ( tsp_dcom_monitor_parms * parms );

externC void os38kVDcomMonClose ( tsp_dcom_monitor_parms * parms );

externC void eo38VDcomDBProc ( tsp_dcom_dispatch_parms * parms );

/*externC void eo38VDcomDispatch ( tsp_dcom_dispatch_parms * parms ); not needed anymore 12-Jan-2000 FF */

externC void eo38VDcomGetDispAddr ( tsp_dcom_co_create_instance_parms * parms );

externC void eo38VDcomReleaseAll ( tsp00_Addr pIliveCacheSink );

externC void eo38VDcomInitSink ( tsp_dcom_init_sink_parms * parms );

externC void eo38VDcomTransEnd ( tsp_dcom_dispatch_parms * parms );

externC void eo38VDcomInvalidate ( tsp_dcom_co_create_instance_parms * parms );

externC long sql38CoCreateInstance(CLSID* rclsid, tsp00_Addr pDebugLocation,
                                   DWORD dwClsContext, REFIID riid, LPVOID FAR* ppv);

externC long sql38CoGetClassObject(CLSID* rclsid, DWORD dwClsContext, 
                                   tsp00_Addr pDebugLocation,
                                   REFIID riid, LPVOID FAR* ppv);

externC long sql38CoInitializeEx( void );

externC long sql38CoUninitialize( void );

externC void eo38LoadLibraryEx(const char *path, 
                               bool      loadGlobal,
                               HANDLE    *hd,
                               char      *errtext,
                               int       errtext_size);

externC void eo38FreeLibrary(HANDLE      hd,
                             bool        *ok,
                             char        *errtext,
                             int         errtext_size);

externC void eo38CTraceBack( tsp00_Addr hd ); /*PTS 1106505 FF */
#endif

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/eo/heo38.h <==
/* @lastChanged: "1998-09-04  9:41"

  * @filename:   heo38k.h
  * @purpose:    "COM"
  * @release:    7.2.0.0
  * @see:        "-.-"
  *
  * @copyright:  "Copyright by SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*/


#ifndef HEO38_H
#define HEO38_H

#include "gsp00.h"
#include "gco00.h"

externC void eo38CoCreateInstance ( tsp_dcom_co_create_instance_parms * parms );

externC void eo38CoGetClassObject ( tsp_dcom_co_create_instance_parms * parms );

externC BOOLEAN eo38CoInitialize ( void );

externC void eo38IIdILiveCacheSpec ( tsp_c16 * iid );

externC void eo38InitializeDebugServer (tsp_dcom_co_create_instance_parms * parms);

externC void eo38ReleaseInstance ( tsp_dcom_release_instance_parms * parms );

externC void eo38ReleaseProxies ();

externC void eo38RemoveProxy ( tsp00_Uint4 session );

externC void eo38UnInitialize ( void );

externC void eo38VDcomCreateInstance ( tsp_dcom_co_create_instance_parms * parms );

externC void eo38VDcomMonOpen ( tsp_dcom_monitor_parms * parms );

externC void eo38VDcomMonNext ( tsp_dcom_monitor_parms * parms );

externC void eo38VDcomMonClose ( tsp_dcom_monitor_parms * parms );

externC void eo38VDcomDBProc ( tsp_dcom_dispatch_parms * parms );

externC void eo38VDcomGetDispAddr ( tsp_dcom_co_create_instance_parms * parms );

externC void eo38VDcomReleaseAll ( tsp00_Addr pIliveCacheSink );

externC void eo38VDcomInitSink ( tsp_dcom_init_sink_parms * parms );

externC void eo38VDcomTransEnd ( tsp_dcom_dispatch_parms * parms );

externC void eo38VDcomInvalidate ( tsp_dcom_co_create_instance_parms * parms );

externC long sql38CoCreateInstance(CLSID* rclsid, REFIID riid, LPVOID FAR* ppv);

externC long sql38CoGetClassObject(CLSID* rclsid, REFIID riid, LPVOID FAR* ppv);

externC void eo38LoadLibraryEx(const char *path, 
                               bool      loadGlobal,
                               HANDLE    *hd,
                               char      *errtext,
                               int       errtext_size);

externC void eo38FreeLibrary(HANDLE      hd,
                             bool        *ok,
                             char        *errtext,
                             int         errtext_size);

externC void eo38CTraceBack( tsp00_Addr hd ); /*PTS 1106505 FF */

#endif
